Renders circlized assist network for game or entire season and allows for highlight of a single player if desired.
circle_assist_net(
team,
season,
highlight_player = NA,
highlight_color = NA,
three_weights = T,
threshold = 0,
message = NA,
return_stats = T
)Team to create network for
Season, as a character, (e.g. "2018-19"), or vector of ESPN game_ids. for which data to use in network.
Name of player to highlight in assist network. `NA` yields full-team assist network with no player highlighting. Default = `NA`.
Color of player links to be highlighted. `NA` if ```highlight_player``` is `NA`.
Logical indicating whether to give extra weight for assisted three-point shots. If TRUE, assisted three-point shots will be given weight 1.5 (as opposed to weight 1). Default = `TRUE`.
Number between 0-1 indicating minimum percentage of team assists/baskets a player needs to exceed to be included in network. Default = 0.
User-supplied plot title to overwrite default plot title, if desired. Default = `NA`.
Return Assist Network-related statistics (default = `TRUE`)
List with network statistics
"clust_coeff" - Network Clustering Coefficient
"page_ranks" - Player Page Ranks in network
"hub_scores" - Player Hub Scores in network
"auth_scores" - Player Authority Scores in network
"ast_freq" - Player percentage of team's assists
"shot_freq" - Player percenatge of scoring on team's assisted baskets