Scrapes the current season's Play-by-Play data for desired team. Team is assumed to be the ESPN team name, which can be looked up in the ids dataframe.
get_pbp(team, season = current_season, extra_parse = T)Team to get Play-by-Play data for
Season for which to get schedule. In form "2019-20". Default equals current season.
Logical whether to link shot variables and possesion parsing (Default = TRUE).
A data frame of the team's Play-by-Play data for the specified season.