- ncaa_name
the name of the team, as listed on the NCAA website (same as dict$NCAA)
- espn_name
the name of the team, as listed in ESPN URLs (same as dict$ESPN)
- primary_color
hexcode for team's primary color
- secondary_color
hexcode for team's secondary color, when available
- tertiary_color
hexcode for team's tertiary color, when available
- color_4
hexcode for team's 4th color, when available
- color_5
hexcode for team's 5th color, when available
- color_6
hexcode for team's 6th color, when available